Changelog
=========

v2020.05.01
-----------

Changes
~~~~~~~
- Add support for datasource open/close [ohad83]
- Switch to itjson endpoints [Mike Kershaw / Dragorn]

v2019.05.02
-----------

Changes
~~~~~~~
- Support Python 3.5. [ashmastaflash]
- Add MANIFEST.in. [ashmastaflash]


2019.05.01 (2019-05-20)
-----------------------

New
~~~
- Refactor complete. [ashmastaflash]

  Closes #1

Changes
~~~~~~~
- Add developer notes to README.rst. [ashmastaflash]
- Add configs for gitchangelog and rtd. [ashmastaflash]

Other
~~~~~
- Update docs. [Mike Kershaw / Dragorn]
- Start extracting module. [Mike Kershaw / Dragorn]
- Started repo. [Mike Kershaw / Dragorn]


